import { CfnProject } from 'aws-cdk-lib/aws-datazone';
import { Construct } from 'constructs';
import { CustomAssetType } from './datazone-custom-asset-type-factory';
import { DataZoneMskAssetTypeProps } from './datazone-msk-asset-type-props';
import { TrackedConstruct } from '../../../utils';
/**
 * A DataZone custom asset type representing an MSK topic.
 *
 * @example
 * new dsf.governance.DataZoneMskAssetType(this, 'MskAssetType', {
 *   domainId: 'aba_dc999t9ime9sss',
 *   projectId: '999999b3m5cpz',
 * });
 */
export declare class DataZoneMskAssetType extends TrackedConstruct {
    /**
     * The custom asset type for MSK
     */
    readonly mskCustomAssetType: CustomAssetType;
    /**
     * The project owning the MSK asset type
     */
    readonly owningProject?: CfnProject;
    private readonly removalPolicy;
    /**
     * Construct an instance of the DataZoneMskAssetType
     * @param scope the Scope of the CDK Construct
     * @param id the ID of the CDK Construct
     * @param props The DataZoneMskAssetTypeProps properties
     */
    constructor(scope: Construct, id: string, props: DataZoneMskAssetTypeProps);
}
