import { RemovalPolicy } from 'aws-cdk-lib';
import { ISecurityGroup, IVpc } from 'aws-cdk-lib/aws-ec2';
import { ManagedPolicy } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { CfnCluster } from 'aws-cdk-lib/aws-msk';
import { Construct } from 'constructs';
import { BrokerLogging, ClientAuthentication, ClusterConfigurationInfo } from './msk-utils';
import { DsfProvider } from '../../../utils/lib/dsf-provider';
/**
 * @internal
 *
 * @param scope
 * @param brokerLoggingProps
 * @returns
 */
export declare function monitoringSetup(scope: Construct, id: string, removalPolicy: RemovalPolicy, brokerLoggingProps?: BrokerLogging): [any, ILogGroup?];
/**
 * @internal
 *
 * @param clientAuthenticationProps
 * @returns
 */
export declare function clientAuthenticationSetup(clientAuthenticationProps?: ClientAuthentication): [
    CfnCluster.ClientAuthenticationProperty,
    boolean,
    boolean
];
/**
 * @internal
 */
export declare function updateClusterConnectivity(scope: Construct, cluster: CfnCluster, vpc: IVpc, subnetSelectionIds: string[], removalPolicy: RemovalPolicy, brokerAtRestEncryptionKey: IKey, placeClusterHandlerInVpc?: boolean, environmentEncryption?: IKey): DsfProvider;
/**
 * @internal
 */
export declare function applyClusterConfiguration(scope: Construct, cluster: CfnCluster, vpc: IVpc, subnetSelectionIds: string[], removalPolicy: RemovalPolicy, brokerAtRestEncryptionKey: IKey, configuration: ClusterConfigurationInfo, placeClusterHandlerInVpc?: boolean, environmentEncryption?: IKey): DsfProvider;
export declare function getVpcPermissions(scope: Construct, securityGroup: ISecurityGroup, subnets: string[], id: string): ManagedPolicy;
export declare function createLogGroup(scope: Construct, id: string, removalPolicy: RemovalPolicy): ILogGroup;
