import { ISecurityGroup } from 'aws-cdk-lib/aws-ec2';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { IFunction } from 'aws-cdk-lib/aws-lambda';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { Construct } from 'constructs';
import { DsfProviderProps } from './dsf-provider-props';
/**
 * @internal
 */
export declare class DsfProvider extends Construct {
    private static readonly CR_RUNTIME;
    private static readonly LOG_RETENTION;
    private static readonly FUNCTION_TIMEOUT;
    /**
     * The Custom Resouce Provider created
     */
    readonly serviceToken: string;
    /**
     * The CloudWatch Log Group for the OnEventHandler Lambda Function
     */
    readonly onEventHandlerLogGroup: ILogGroup;
    /**
     * The IAM Role for the onEventHandler Lambba Function
     */
    readonly onEventHandlerRole: IRole;
    /**
     * The Lambda Function for the onEventHandler
     */
    readonly onEventHandlerFunction: IFunction;
    /**
     * The CloudWatch Log Group for the isCompleteHandler Lambda Function
     */
    readonly isCompleteHandlerLog?: ILogGroup;
    /**
     * The IAM Role for the isCompleteHandler Lambba Function
     */
    readonly isCompleteHandlerRole?: IRole;
    /**
     * The Lambda Function for the isCompleteHandler
     */
    readonly isCompleteHandlerFunction?: IFunction;
    /**
     * The list of EC2 Security Groups used by the Lambda Functions
     */
    readonly securityGroups?: ISecurityGroup[];
    /**
     * The CloudWatch Log Group for the custom resource cleaning up lambda ENIs
     */
    readonly cleanUpLogGroup?: ILogGroup;
    /**
     * The Lambda function for the custom resource cleaning up lambda ENIs
     */
    readonly cleanUpFunction?: IFunction;
    /**
     * The IAM Role for the cleanUp Lambba Function
     */
    readonly cleanUpRole?: IRole;
    private readonly removalPolicy;
    private readonly accountInfo;
    private readonly subnets?;
    private readonly cleanUpCr?;
    private readonly vpcPolicy?;
    private readonly vpc?;
    constructor(scope: Construct, id: string, props: DsfProviderProps);
    private createLambdaExecutionRole;
    private createLogGroup;
    private createHandler;
    private getVpcPermissions;
}
