import { CfnOutput, Stack } from 'aws-cdk-lib';
import { Project } from 'aws-cdk-lib/aws-codebuild';
import { PolicyStatement } from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { CICDStage } from './application-stage';
/**
 * Stack that contains resources related to running the
 * integration test.
 */
export declare class IntegrationTestStack extends Stack {
    /**
     * The CodeBuild Project that's going to run the
     * integration test.
     */
    readonly integrationTestCodeBuildProject: Project;
    /**
     * Constructor for the IntegrationTestStack
     * @param scope the scope of the construct
     * @param id the id of the construct
     * @param stage the stage in the CI/CD pipeline
     * @param integScriptPath the path of the integration test script
     * @param integTestCommand the command to be used to run the integration test script
     * @param stackOutputsEnv the output from the application stack to use as input to the test script
     * @param integTestPermissions IAM permissions for the integration test script
     */
    constructor(scope: Construct, id: string, stage: CICDStage, integScriptPath: string, integTestCommand: string, stackOutputsEnv?: Record<string, CfnOutput>, integTestPermissions?: PolicyStatement[]);
}
